@@ -238,7 +238,7 @@ Rcgminb <- function(par, fn, gr, lower, upper, bdmsk = NULL, control = list(), .
     if (trace > 0) {
         cat("Initial function value=", f, "\n")
     }
-    if (class(f) == "try-error") {
+    if (inherits(f,"try-error")) {
         msg <- "Initial point is infeasible."
         if (trace > 0) 
             cat(msg, "\n")
